@@ -1,4 +1,5 @@
-package Sub::Call::Tail;
+package Sub::Call::Tail; # git description: Sub-Call-Tail-0.05-7-gfee82bd
+# ABSTRACT: Tail calls for subroutines and methods
 
 use strict;
 use warnings;
@@ -7,8 +8,7 @@ require 5.008001;
 use parent qw(Exporter DynaLoader);
 use B::Hooks::OP::Check::EntersubForCV;
 
-our $VERSION = '0.05';
-$VERSION = eval $VERSION;
+our $VERSION = '0.06';
 
 our @EXPORT = our @EXPORT_OK = qw(tail);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
@@ -25,10 +25,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Sub::Call::Tail - Tail calls for subroutines and methods
 
+=head1 VERSION
+
+version 0.06
+
 =head1 SYNOPSIS
 
     use Sub::Call::Tail;
@@ -47,26 +53,51 @@ will cause the invocation to have the same semantics as C<goto &sub>.
 When the C<tail> modifier is compiled the inner subroutine call is transformed
 at compile time into a goto.
 
+=head1 USAGE WARNING
+
+<B>WARNING! The author does not endorse using this module for anything real.
+It was written primarily to demonstrate that such quackery can be achieved.
+Use at your own risk!
+
 =head1 SEE ALSO
 
 L<B::Hooks::OP::Check::EntersubForCV>
 
 L<CPS>
 
-=head1 VERSION CONTROL
-
-L<http://github.com/nothingmuch/Sub-Call-Tail>
-
 =head1 AUTHOR
 
-Yuval Kogman
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-Andrew Main (Zefram)
+=head1 CONTRIBUTORS
 
-=head1 COPYRIGHT & LICENSE
+=for stopwords Karen Etheridge Florian Ragwitz Andrew Main (Zefram) Zefram
 
-	Copyright (c) 2009 Yuval Kogman. All rights reserved
-	This program is free software; you can redistribute
-	it and/or modify it under the same terms as Perl itself.
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Andrew Main (Zefram) <zefram@fysh.org>
+
+=item *
+
+Zefram <zefram@fysh.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
